@@ -897,6 +897,9 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         self.dvm_template_checkbox.setChecked(
             getattr(self.vm, 'template_for_dispvms', False))
 
+        if not hasattr(self.vm, 'template_for_dispvms'):
+            self.dvm_template_checkbox.setEnabled(False)
+
         self.provides_network_checkbox.setChecked(
             getattr(self.vm, 'provides_network', False))
         if self.provides_network_checkbox.isChecked():
@@ -1462,7 +1465,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         if model.temp_full_access_expire_time:
             self.temp_full_access.setChecked(True)
             expire_time = model.temp_full_access_expire_time - \
-                          firewall.datetime.datetime.now().strftime("%s")
+                          firewall.datetime.datetime.now().timestamp()
             self.temp_full_access_time.setValue(int(expire_time / 60))
 
     def disable_all_fw_conf(self):
